[![Documentation Status](https://readthedocs.org/projects/biobb-analysis/badge/?version=latest)](https://biobb-analysis.readthedocs.io/en/latest/?badge=latest)

# biobb_analysis

### Introduction
biobb_analysis is the Biobb module collection to perform analysis of molecular dynamics simulations.
Biobb (BioExcel building blocks) packages are Python building blocks that
create new layer of compatibility and interoperability over popular
bioinformatics tools.
The latest documentation of this package can be found in our readthedocs site:
[latest API documentation](http://biobb_analysis.readthedocs.io/en/latest/).

### Version
v0.1.8 March 2019 Release

### Installation
Using PIP:

        pip install biobb_analysis

Using ANACONDA:

        conda install -c bioconda biobb_analysis

Using DOCKER:

        docker pull mmbirb/biobb_analysis:0.1.7

Using SINGULARITY:

        singularity pull shub://bioexcel/biobb_analysis

### Copyright & Licensing
This software has been developed in the MMB group [http://mmb.irbbarcelona.org](http://mmb.irbbarcelona.org) at the
BSC [http://www.bsc.es](http://www.bsc.es/) & IRB [https://www.irbbarcelona.org](https://www.irbbarcelona.org/) for the European BioExcel [http://bioexcel.eu](http://bioexcel.eu/), funded by the European Commission
(EU H2020 [675728](http://cordis.europa.eu/projects/675728)).

* (c) 2015-2019 [Barcelona Supercomputing Center](https://www.bsc.es/)
* (c) 2015-2019 [Institute for Research in Biomedicine](https://www.irbbarcelona.org/)

Licensed under the
[Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0), see the file
[LICENSE](LICENSE) for details.

![](https://bioexcel.eu/wp-content/uploads/2015/12/Bioexcell_logo_1080px_transp.png "Bioexcel")
